from pymemri.data.schema import Edge, Item, Person, Account, File, OauthFlow
from pymemri.data.schema.photo import Photo
from typing import Optional, List
from hashlib import sha256

class OauthFlow(OauthFlow):
    expiry: Optional[str] = None

class Camera(Item):
    producer: Optional[str] = None
    model: Optional[str] = None

class Photo(Photo):
    creationTime: Optional[str] = None
    filename: Optional[str] = None
    # camera
    camera: List[Camera] = []

class Video(Item):
    data: Optional[bytes] = None

    creationTime: Optional[str] = None
    exifData: Optional[str] = None
    filename: Optional[str] = None
    format: Optional[str] = None
    height: Optional[int] = None
    width: Optional[int] = None
    fps: Optional[int] = None

    #Edges
    file: List[File] = []
    camera: List[Camera] = []

    @classmethod
    def from_bytes(cls, bytes, **kwargs):
        res = cls(data=bytes, id=cls.create_id(), **kwargs)
        file = File(sha256=sha256(bytes).hexdigest())
        res.add_edge("file", file)
        file.id = file.create_id()
        return res


class Document(Item):
    filename: Optional[str] = None
    format: Optional[str] = None
    file: List[File] = None

class Service(Item):
    name: Optional[str] = ""
    #Edges
    photo: List[Photo] = None
    video: List[Video] = None
    documents: List[Document]= None


class Account(Account):

    #Edges
    service: List[Service] = []
