from google.oauth2.credentials import Credentials
from google_auth_oauthlib.flow import InstalledAppFlow
from googleapiclient.discovery import build
import requests

# If modifying these scopes, delete the file token.json.
SCOPES = [
    'https://www.googleapis.com/auth/drive.metadata.readonly',
    'https://www.googleapis.com/auth/drive.readonly',
    'https://www.googleapis.com/auth/photoslibrary.readonly',
    'https://www.googleapis.com/auth/gmail.readonly',
    'https://www.googleapis.com/auth/userinfo.email', 
    'https://www.googleapis.com/auth/userinfo.profile',
    'openid'
]

class GoogleApi:
    def __init__(self):
        self.creds = None
        self.session = requests.Session()

    def start_oauth(self, config):
        flow = InstalledAppFlow.from_client_config(config, SCOPES)
        self.creds = flow.run_local_server(port=0)
        self.set_session()
                
    def use_oauth(self, info):
        self.creds = Credentials.from_authorized_user_info(info, SCOPES)
        self.set_session()

    def get_credentials(self):
        return self.creds
        
    def set_session(self):        
        self.session.headers.update({
            "Authorization": f"Bearer {self.creds.token}"
        })

    def get_media(self):
        service = build('photoslibrary', 'v1', credentials=self.creds, static_discovery=False)
        return service.mediaItems().search().execute()
    

    def get_media_pagination(self, next_page_token=False):
        service = build('photoslibrary', 'v1', credentials=self.creds, static_discovery=False)
        if next_page_token:
            results = service.mediaItems().list(pageToken=next_page_token).execute()
        else:
            results = service.mediaItems().list().execute()
        if "nextPageToken" in results:
            return results, results["nextPageToken"]
        else:
            return results, False

    
    def get_driver_file(self, next_page_token=False):
        service = build('drive', 'v3', credentials=self.creds)
        if next_page_token:
            results = service.files().list(pageSize=10, pageToken=next_page_token).execute()
        else:
            results = service.files().list(pageSize=10).execute()
        if "nextPageToken" in results:
            return results, results["nextPageToken"]
        else:
            return results, False
        
    def get_gmail_account(self):
        service = build('gmail', 'v1', credentials=self.creds)
        results = service.users().getProfile(userId="me").execute()        
        return results['emailAddress']
    
    def get_userinfo(self):
        service = build(serviceName='oauth2', version='v2', credentials=self.creds)
        user_info = service.userinfo().get().execute()
        return user_info
    
    def get_albums(self):
        service = build('photoslibrary', 'v1', credentials=self.creds, static_discovery=False)
        results = service.albums().list().execute()    
        return results
    
    def get_media_data(self, base_url, suffix=""):
        base_url = f"{base_url}{suffix}"
        media_data = self.session.get(base_url)
        return media_data.content